Assuming that RserveApplication is deployed to a dir,
restrserve_stop stops Rserve by executing kill -TERM -- -$PGID
where $PGID is Rserve PID read from configured pid file. PID obtained from
information from Rserve.conf file inside dir.
Usage
restrserve_stop(dir)
Arguments
dir
character, path to the directory where application was deployed
Value
invisibly returns the status of the attempt to kill process group